@@ -1,32 +1,13 @@
-## #old code for wrapping
+#### Wrapper for view ####
 
-## sectionview <- function(model, ...) {
-##   if (class(model)[1]=="km") {
-##     sectionview.km(model=model,...)
-##   } else if (class(model)[1]=="list") {
-##     sectionview.dm(model=model,...)
-##   }
-## }
-
-
-## sectionview3d <- function(model, ...) {
-##   if (class(model)[1]=="km") {
-##     sectionview3d.km(model=model,...)
-##   } else if (class(model)[1]=="list") {
-##     sectionview3d.dm(model=model,...)
-##   }
-## }
-
-## Wrapper for view
 if(!isGeneric("view")) {
     setGeneric(name = "view",
-               def = function(type="auto", model, ...) standardGeneric("view")
+               def = function(model, ...) standardGeneric("view")
                )
 }
 
-setMethod("view", c("character","km"),
-          function(type = "auto",
-                   model, model.type = "UK",
+setMethod("view", "km",
+          function(model, type = "auto",model.type = "UK",
                    center = NULL, axis = NULL,
                    npoints = NULL,
                    col_points = "red",
@@ -114,9 +95,9 @@ setMethod("view", c("character","km"),
           }
           )
 
-setMethod("view", c("character","list"),
-          function(type = "auto",
-                   model,
+setMethod("view", "list",
+          function(model,
+                   type = "auto",
                    center = NULL, axis = NULL,
                    npoints = NULL,
                    col_points = "red",
@@ -198,9 +179,8 @@ setMethod("view", c("character","list"),
           }
           )
 
-setMethod("view", c("character","function"),
-          function(type = "auto",
-                   model , dim,
+setMethod("view", "function",
+          function(model ,type = "auto", dim,
                    center = NULL, axis = NULL,
                    npoints = NULL,
                    col = "blue",
@@ -226,7 +206,7 @@ setMethod("view", c("character","function"),
               }
 
               if (type == "section" || type == "xy")
-                  sectionview.fun(fun = model, dim = dim,
+                  sectionview.function(model, dim = dim,
                                   center = center, axis = axis,
                                   npoints = ifelse(is.null(npoints),100,npoints),
                                   col_surf = col,
@@ -241,7 +221,7 @@ setMethod("view", c("character","function"),
                                   ...)
 
               if (type == "section3d" || type == "3d")
-                  sectionview3d.fun(fun = model, dim = dim,
+                  sectionview3d.function(model, dim = dim,
                                     center = center, axis = axis,
                                     npoints = ifelse(is.null(npoints),20,npoints),
                                     col = col,
@@ -255,7 +235,7 @@ setMethod("view", c("character","function"),
                                     ...)
 
               if (type == "contour")
-                  contourview.fun(fun = model, dim = dim,
+                  contourview.function(model, dim = dim,
                                   center = center, axis = axis,
                                   npoints = ifelse(is.null(npoints),20,npoints),
                                   col = col,
@@ -272,14 +252,45 @@ setMethod("view", c("character","function"),
           }
           )
 
+## #' Plot a view of a kriging, modelPredict model or function.
+## #' @description Standard entry point function to plot a  view of a kriging, modelPredict model or function. It is useful for a better understanding of a model behaviour. This function is just a wrapping of all other ploting functions (section, contour, section3d), for all supported types (km, list, function).
+## #' @param model an object of class \code{"km"}, a list that can be used in a \code{"modelPredict"} call, or a function.
+## #' @param type a string to describe the type of view to display: "auto", "section", "xy", "section3d", "3d", "contour".
+## #' @param ... other arguments of the \code{sectionview}, \code{sectionview3d} or \code{contourview} function
+## #' @export
+## #' @examples
+## #' ## A 2D example - Branin-Hoo function
+## #' ## a 16-points factorial design, and the corresponding response
+## #' d <- 2; n <- 16
+## #' design.fact <- expand.grid(seq(0, 1, length = 4), seq(0, 1, length = 4))
+## #' design.fact <- data.frame(design.fact); names(design.fact) <- c("x1", "x2")
+## #' y <- branin(design.fact)
+## #'
+## #' ## kriging model 1 : matern5_2 covariance structure, no trend, no nugget effect
+## #' m1 <- km(design = design.fact, response = y)
+## #'
+## #' view(m1,"3d")
+## #'
+## #' view(branin,"3d", dim = 2, col='red', add = TRUE)
+## view <- function(model,...){
+##     UseMethod("view")
+## }
+
+
+#### Wrapper for sectionview ####
 
-## Wrapper for sectionview
 if(!isGeneric("sectionview")) {
     setGeneric(name = "sectionview",
                def = function(model, ...) standardGeneric("sectionview")
                )
 }
 
+#' View the model in a section view.
+#' @param km kriging model
+#' @importFrom methods setMethod
+#' @method sectionview km
+#' @rdname km-methods
+#' @aliases sectionview,km,km-method
 setMethod("sectionview", "km",
           function(model,
                    type = "UK",
@@ -321,6 +332,12 @@ setMethod("sectionview", "km",
           }
           )
 
+#' View the model in a section view.
+#' @param list DiceEval model
+#' @importFrom methods setMethod
+#' @method sectionview list
+#' @rdname list-methods
+#' @aliases sectionview,list,list-method
 setMethod("sectionview", "list",
           function(model,
                    center = NULL,
@@ -356,6 +373,12 @@ setMethod("sectionview", "list",
           }
           )
 
+#' View the model in a section view.
+#' @param function function, taken as model
+#' @importFrom methods setMethod
+#' @method sectionview function
+#' @rdname function-methods
+#' @aliases sectionview,function,function-method
 setMethod("sectionview", "function",
           function(model,dim,
                    center = NULL, axis = NULL,
@@ -371,7 +394,7 @@ setMethod("sectionview", "function",
                    title = NULL,
                    ...){
 
-              sectionview.fun(fun = model,
+              sectionview.function(model = model,
                               dim = dim,
                               center = center, axis = axis,
                               npoints = npoints,
@@ -388,13 +411,45 @@ setMethod("sectionview", "function",
           }
           )
 
-#Wrapper for sectionview3d
+
+#' Plot a section view of a kriging or modelPredict model including design points, or a function.
+#' @description Plot one section view per dimension of a kriging, \code{modelPredict} model or function. It is useful for a better understanding of a model behaviour (including uncertainty).
+#' @param model an object of class \code{"km"}, a list that can be used in a \code{"modelPredict"} call, or a function.
+#' @param ... other arguments of the \code{contourview.km}, \code{contourview.list} or \code{contourview.function} function
+#' @importFrom DiceKriging branin
+#' @export
+#' @examples
+#' ## A 2D example - Branin-Hoo function
+#' ## a 16-points factorial design, and the corresponding response
+#' d <- 2; n <- 16
+#' design.fact <- expand.grid(seq(0, 1, length = 4), seq(0, 1, length = 4))
+#' design.fact <- data.frame(design.fact); names(design.fact) <- c("x1", "x2")
+#' y <- branin(design.fact)
+#'
+#' ## kriging model 1 : matern5_2 covariance structure, no trend, no nugget effect
+#' m1 <- km(design = design.fact, response = y)
+#'
+#' sectionview(m1, center = c(.333, .333))
+#'
+#' sectionview(branin, dim = 2, center = c(.333, .333), add=TRUE)
+sectionview <- function(model, ...){
+    UseMethod("sectionview")
+}
+
+
+#### Wrapper for sectionview3d ####
 if(!isGeneric("sectionview3d")) {
     setGeneric(name = "sectionview3d",
                def = function(model, ...) standardGeneric("sectionview3d")
                )
 }
 
+#' View the model in a section (3D) view.
+#' @param km kriging model
+#' @importFrom methods setMethod
+#' @method sectionview3d km
+#' @rdname km-methods
+#' @aliases sectionview3d,km,km-method
 setMethod("sectionview3d", "km",
           function(model, type = "UK",
                    center = NULL, axis = NULL,
@@ -434,6 +489,12 @@ setMethod("sectionview3d", "km",
           }
           )
 
+#' View the model in a section (3D) view.
+#' @param list DiceEval model
+#' @importFrom methods setMethod
+#' @method sectionview3d list
+#' @rdname list-methods
+#' @aliases sectionview3d,list,list-method
 setMethod("sectionview3d", "list",
           function(model,
                    center = NULL, axis = NULL,
@@ -467,6 +528,12 @@ setMethod("sectionview3d", "list",
           }
           )
 
+#' View the model in a section (3D) view.
+#' @param function function, taken as model
+#' @importFrom methods setMethod
+#' @method sectionview3d function
+#' @rdname function-methods
+#' @aliases sectionview3d,function,function-method
 setMethod("sectionview3d", "function",
           function(model,dim,
                    center = NULL, axis = NULL,
@@ -481,7 +548,7 @@ setMethod("sectionview3d", "function",
                    title = NULL,
                    ...){
 
-              sectionview3d.fun(fun = model, dim = dim,
+              sectionview3d.function(model, dim = dim,
                                 center = center, axis = axis,
                                 npoints = npoints,
                                 col = col,
@@ -496,13 +563,45 @@ setMethod("sectionview3d", "function",
           }
           )
 
-#Wrapper for contourview
+
+#' Plot a 3-D (using RGL) view of a kriging or modelPredict model, including design points
+#' @description Plot a 3-D view of a kriging or modelPredict model. It is useful for a better understanding of a model behaviour.
+#' @param model an object of class \code{"km"}, a list that can be used in a \code{"modelPredict"} call, or a function.
+#' @param ... other arguments of the \code{contourview.km}, \code{contourview.list} or \code{contourview.function} function
+#' @importFrom methods setMethod
+#' @importFrom DiceKriging branin
+#' @export
+#' @examples
+#' ## A 2D example - Branin-Hoo function
+#' ## a 16-points factorial design, and the corresponding response
+#' d <- 2; n <- 16
+#' design.fact <- expand.grid(seq(0, 1, length = 4), seq(0, 1, length = 4))
+#' design.fact <- data.frame(design.fact); names(design.fact) <- c("x1", "x2")
+#' y <- branin(design.fact)
+#'
+#' ## kriging model 1 : matern5_2 covariance structure, no trend, no nugget effect
+#' m1 <- km(design = design.fact, response = y)
+#'
+#' sectionview3d(m1)
+#'
+#' sectionview3d(branin, dim = 2, add=TRUE)
+sectionview3d <- function(model, ...){
+    UseMethod("sectionview3d")
+}
+
+#### Wrapper for contourview ####
 if(!isGeneric("contourview")) {
     setGeneric(name = "contourview",
                def = function(model, ...) standardGeneric("contourview")
-               )
+           )
 }
 
+#' View the model in a contour (2D) view.
+#' @param km kriging model
+#' @importFrom methods setMethod
+#' @method contourview km
+#' @rdname km-methods
+#' @aliases contourview,km,km-method
 setMethod("contourview", "km",
           function(model, type = "UK",
                    center = NULL, axis = NULL,
@@ -538,6 +637,12 @@ setMethod("contourview", "km",
           }
           )
 
+#' View the model in a contour (2D) view.
+#' @param list DiceEval model
+#' @importFrom methods setMethod
+#' @method contourview list
+#' @rdname list-methods
+#' @aliases contourview,list,list-method
 setMethod("contourview", "list",
           function(model,
                    center = NULL, axis = NULL,
@@ -573,6 +678,12 @@ setMethod("contourview", "list",
           }
           )
 
+#' View the model in a contour (2D) view.
+#' @param function function, taken as model
+#' @importFrom methods setMethod
+#' @method contourview function
+#' @rdname function-methods
+#' @aliases contourview,function,function-method
 setMethod("contourview", "function",
           function(model,dim,
                    center = NULL, axis = NULL,
@@ -588,7 +699,7 @@ setMethod("contourview", "function",
                    title = NULL,
                    ...){
 
-              contourview.fun(fun = model, dim = dim,
+              contourview.function(model = model, dim = dim,
                               center = center, axis = axis,
                               npoints = npoints,
                               col = col,
@@ -603,3 +714,28 @@ setMethod("contourview", "function",
                               ...)
           }
           )
+
+#' Plot a contour view of a kriging or modelPredict model including design points, or a function.
+#' @description Plot a contour view of a kriging or modelPredict model. It is useful for a better understanding of a model behaviour.
+#' @param model an object of class \code{"km"}, a list that can be used in a \code{"modelPredict"} call, or a function.
+#' @param ... other arguments of the \code{contourview.km}, \code{contourview.list} or \code{contourview.function} function
+#' @importFrom DiceKriging branin
+#' @importFrom DiceKriging km
+#' @export
+#' @examples
+#' ## A 2D example - Branin-Hoo function
+#' ## a 16-points factorial design, and the corresponding response
+#' d <- 2; n <- 16
+#' design.fact <- expand.grid(seq(0, 1, length = 4), seq(0, 1, length = 4))
+#' design.fact <- data.frame(design.fact); names(design.fact) <- c("x1", "x2")
+#' y <- branin(design.fact)
+#'
+#' ## kriging model 1 : matern5_2 covariance structure, no trend, no nugget effect
+#' m1 <- km(design = design.fact, response = y)
+#'
+#' contourview(m1)
+#'
+#' contourview(branin, dim = 2, add=TRUE)
+contourview <- function(model, ...){
+    UseMethod("contourview")
+}
